@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Shift-Reduce Parser Application
 #
-# Copyright (C) 2001-2019 NLTK Project
+# Copyright (C) 2001-2020 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
@@ -62,8 +62,8 @@ Keyboard Shortcuts::
 
 """
 
-from six.moves.tkinter_font import Font
-from six.moves.tkinter import IntVar, Listbox, Button, Frame, Label, Menu, Scrollbar, Tk
+from tkinter.font import Font
+from tkinter import IntVar, Listbox, Button, Frame, Label, Menu, Scrollbar, Tk
 
 from nltk.tree import Tree
 from nltk.parse import SteppingShiftReduceParser
@@ -101,7 +101,7 @@ class ShiftReduceApp(object):
 
         # Set up the main window.
         self._top = Tk()
-        self._top.title('Shift Reduce Parser Application')
+        self._top.title("Shift Reduce Parser Application")
 
         # Animations.  animating_lock is a lock to prevent the demo
         # from performing new operations while it's animating.
@@ -131,7 +131,7 @@ class ShiftReduceApp(object):
 
         # Reset the demo, and set the feedback frame to empty.
         self.reset()
-        self._lastoper1['text'] = ''
+        self._lastoper1["text"] = ""
 
     #########################################
     ##  Initialization Helpers
@@ -144,171 +144,171 @@ class ShiftReduceApp(object):
 
         # TWhat's our font size (default=same as sysfont)
         self._size = IntVar(root)
-        self._size.set(self._sysfont.cget('size'))
+        self._size.set(self._sysfont.cget("size"))
 
-        self._boldfont = Font(family='helvetica', weight='bold', size=self._size.get())
-        self._font = Font(family='helvetica', size=self._size.get())
+        self._boldfont = Font(family="helvetica", weight="bold", size=self._size.get())
+        self._font = Font(family="helvetica", size=self._size.get())
 
     def _init_grammar(self, parent):
         # Grammar view.
         self._prodframe = listframe = Frame(parent)
-        self._prodframe.pack(fill='both', side='left', padx=2)
+        self._prodframe.pack(fill="both", side="left", padx=2)
         self._prodlist_label = Label(
-            self._prodframe, font=self._boldfont, text='Available Reductions'
+            self._prodframe, font=self._boldfont, text="Available Reductions"
         )
         self._prodlist_label.pack()
         self._prodlist = Listbox(
             self._prodframe,
-            selectmode='single',
-            relief='groove',
-            background='white',
-            foreground='#909090',
+            selectmode="single",
+            relief="groove",
+            background="white",
+            foreground="#909090",
             font=self._font,
-            selectforeground='#004040',
-            selectbackground='#c0f0c0',
+            selectforeground="#004040",
+            selectbackground="#c0f0c0",
         )
 
-        self._prodlist.pack(side='right', fill='both', expand=1)
+        self._prodlist.pack(side="right", fill="both", expand=1)
 
         self._productions = list(self._parser.grammar().productions())
         for production in self._productions:
-            self._prodlist.insert('end', (' %s' % production))
+            self._prodlist.insert("end", (" %s" % production))
         self._prodlist.config(height=min(len(self._productions), 25))
 
         # Add a scrollbar if there are more than 25 productions.
         if 1:  # len(self._productions) > 25:
-            listscroll = Scrollbar(self._prodframe, orient='vertical')
+            listscroll = Scrollbar(self._prodframe, orient="vertical")
             self._prodlist.config(yscrollcommand=listscroll.set)
             listscroll.config(command=self._prodlist.yview)
-            listscroll.pack(side='left', fill='y')
+            listscroll.pack(side="left", fill="y")
 
         # If they select a production, apply it.
-        self._prodlist.bind('<<ListboxSelect>>', self._prodlist_select)
+        self._prodlist.bind("<<ListboxSelect>>", self._prodlist_select)
 
         # When they hover over a production, highlight it.
         self._hover = -1
-        self._prodlist.bind('<Motion>', self._highlight_hover)
-        self._prodlist.bind('<Leave>', self._clear_hover)
+        self._prodlist.bind("<Motion>", self._highlight_hover)
+        self._prodlist.bind("<Leave>", self._clear_hover)
 
     def _init_bindings(self):
         # Quit
-        self._top.bind('<Control-q>', self.destroy)
-        self._top.bind('<Control-x>', self.destroy)
-        self._top.bind('<Alt-q>', self.destroy)
-        self._top.bind('<Alt-x>', self.destroy)
+        self._top.bind("<Control-q>", self.destroy)
+        self._top.bind("<Control-x>", self.destroy)
+        self._top.bind("<Alt-q>", self.destroy)
+        self._top.bind("<Alt-x>", self.destroy)
 
         # Ops (step, shift, reduce, undo)
-        self._top.bind('<space>', self.step)
-        self._top.bind('<s>', self.shift)
-        self._top.bind('<Alt-s>', self.shift)
-        self._top.bind('<Control-s>', self.shift)
-        self._top.bind('<r>', self.reduce)
-        self._top.bind('<Alt-r>', self.reduce)
-        self._top.bind('<Control-r>', self.reduce)
-        self._top.bind('<Delete>', self.reset)
-        self._top.bind('<u>', self.undo)
-        self._top.bind('<Alt-u>', self.undo)
-        self._top.bind('<Control-u>', self.undo)
-        self._top.bind('<Control-z>', self.undo)
-        self._top.bind('<BackSpace>', self.undo)
+        self._top.bind("<space>", self.step)
+        self._top.bind("<s>", self.shift)
+        self._top.bind("<Alt-s>", self.shift)
+        self._top.bind("<Control-s>", self.shift)
+        self._top.bind("<r>", self.reduce)
+        self._top.bind("<Alt-r>", self.reduce)
+        self._top.bind("<Control-r>", self.reduce)
+        self._top.bind("<Delete>", self.reset)
+        self._top.bind("<u>", self.undo)
+        self._top.bind("<Alt-u>", self.undo)
+        self._top.bind("<Control-u>", self.undo)
+        self._top.bind("<Control-z>", self.undo)
+        self._top.bind("<BackSpace>", self.undo)
 
         # Misc
-        self._top.bind('<Control-p>', self.postscript)
-        self._top.bind('<Control-h>', self.help)
-        self._top.bind('<F1>', self.help)
-        self._top.bind('<Control-g>', self.edit_grammar)
-        self._top.bind('<Control-t>', self.edit_sentence)
+        self._top.bind("<Control-p>", self.postscript)
+        self._top.bind("<Control-h>", self.help)
+        self._top.bind("<F1>", self.help)
+        self._top.bind("<Control-g>", self.edit_grammar)
+        self._top.bind("<Control-t>", self.edit_sentence)
 
         # Animation speed control
-        self._top.bind('-', lambda e, a=self._animate: a.set(20))
-        self._top.bind('=', lambda e, a=self._animate: a.set(10))
-        self._top.bind('+', lambda e, a=self._animate: a.set(4))
+        self._top.bind("-", lambda e, a=self._animate: a.set(20))
+        self._top.bind("=", lambda e, a=self._animate: a.set(10))
+        self._top.bind("+", lambda e, a=self._animate: a.set(4))
 
     def _init_buttons(self, parent):
         # Set up the frames.
         self._buttonframe = buttonframe = Frame(parent)
-        buttonframe.pack(fill='none', side='bottom')
+        buttonframe.pack(fill="none", side="bottom")
         Button(
             buttonframe,
-            text='Step',
-            background='#90c0d0',
-            foreground='black',
+            text="Step",
+            background="#90c0d0",
+            foreground="black",
             command=self.step,
-        ).pack(side='left')
+        ).pack(side="left")
         Button(
             buttonframe,
-            text='Shift',
+            text="Shift",
             underline=0,
-            background='#90f090',
-            foreground='black',
+            background="#90f090",
+            foreground="black",
             command=self.shift,
-        ).pack(side='left')
+        ).pack(side="left")
         Button(
             buttonframe,
-            text='Reduce',
+            text="Reduce",
             underline=0,
-            background='#90f090',
-            foreground='black',
+            background="#90f090",
+            foreground="black",
             command=self.reduce,
-        ).pack(side='left')
+        ).pack(side="left")
         Button(
             buttonframe,
-            text='Undo',
+            text="Undo",
             underline=0,
-            background='#f0a0a0',
-            foreground='black',
+            background="#f0a0a0",
+            foreground="black",
             command=self.undo,
-        ).pack(side='left')
+        ).pack(side="left")
 
     def _init_menubar(self, parent):
         menubar = Menu(parent)
 
         filemenu = Menu(menubar, tearoff=0)
         filemenu.add_command(
-            label='Reset Parser', underline=0, command=self.reset, accelerator='Del'
+            label="Reset Parser", underline=0, command=self.reset, accelerator="Del"
         )
         filemenu.add_command(
-            label='Print to Postscript',
+            label="Print to Postscript",
             underline=0,
             command=self.postscript,
-            accelerator='Ctrl-p',
+            accelerator="Ctrl-p",
         )
         filemenu.add_command(
-            label='Exit', underline=1, command=self.destroy, accelerator='Ctrl-x'
+            label="Exit", underline=1, command=self.destroy, accelerator="Ctrl-x"
         )
-        menubar.add_cascade(label='File', underline=0, menu=filemenu)
+        menubar.add_cascade(label="File", underline=0, menu=filemenu)
 
         editmenu = Menu(menubar, tearoff=0)
         editmenu.add_command(
-            label='Edit Grammar',
+            label="Edit Grammar",
             underline=5,
             command=self.edit_grammar,
-            accelerator='Ctrl-g',
+            accelerator="Ctrl-g",
         )
         editmenu.add_command(
-            label='Edit Text',
+            label="Edit Text",
             underline=5,
             command=self.edit_sentence,
-            accelerator='Ctrl-t',
+            accelerator="Ctrl-t",
         )
-        menubar.add_cascade(label='Edit', underline=0, menu=editmenu)
+        menubar.add_cascade(label="Edit", underline=0, menu=editmenu)
 
         rulemenu = Menu(menubar, tearoff=0)
         rulemenu.add_command(
-            label='Step', underline=1, command=self.step, accelerator='Space'
+            label="Step", underline=1, command=self.step, accelerator="Space"
         )
         rulemenu.add_separator()
         rulemenu.add_command(
-            label='Shift', underline=0, command=self.shift, accelerator='Ctrl-s'
+            label="Shift", underline=0, command=self.shift, accelerator="Ctrl-s"
         )
         rulemenu.add_command(
-            label='Reduce', underline=0, command=self.reduce, accelerator='Ctrl-r'
+            label="Reduce", underline=0, command=self.reduce, accelerator="Ctrl-r"
         )
         rulemenu.add_separator()
         rulemenu.add_command(
-            label='Undo', underline=0, command=self.undo, accelerator='Ctrl-u'
+            label="Undo", underline=0, command=self.undo, accelerator="Ctrl-u"
         )
-        menubar.add_cascade(label='Apply', underline=0, menu=rulemenu)
+        menubar.add_cascade(label="Apply", underline=0, menu=rulemenu)
 
         viewmenu = Menu(menubar, tearoff=0)
         viewmenu.add_checkbutton(
@@ -319,41 +319,41 @@ class ShiftReduceApp(object):
         )
         viewmenu.add_separator()
         viewmenu.add_radiobutton(
-            label='Tiny',
+            label="Tiny",
             variable=self._size,
             underline=0,
             value=10,
             command=self.resize,
         )
         viewmenu.add_radiobutton(
-            label='Small',
+            label="Small",
             variable=self._size,
             underline=0,
             value=12,
             command=self.resize,
         )
         viewmenu.add_radiobutton(
-            label='Medium',
+            label="Medium",
             variable=self._size,
             underline=0,
             value=14,
             command=self.resize,
         )
         viewmenu.add_radiobutton(
-            label='Large',
+            label="Large",
             variable=self._size,
             underline=0,
             value=18,
             command=self.resize,
         )
         viewmenu.add_radiobutton(
-            label='Huge',
+            label="Huge",
             variable=self._size,
             underline=0,
             value=24,
             command=self.resize,
         )
-        menubar.add_cascade(label='View', underline=0, menu=viewmenu)
+        menubar.add_cascade(label="View", underline=0, menu=viewmenu)
 
         animatemenu = Menu(menubar, tearoff=0)
         animatemenu.add_radiobutton(
@@ -364,81 +364,81 @@ class ShiftReduceApp(object):
             underline=0,
             variable=self._animate,
             value=20,
-            accelerator='-',
+            accelerator="-",
         )
         animatemenu.add_radiobutton(
             label="Normal Animation",
             underline=0,
             variable=self._animate,
             value=10,
-            accelerator='=',
+            accelerator="=",
         )
         animatemenu.add_radiobutton(
             label="Fast Animation",
             underline=0,
             variable=self._animate,
             value=4,
-            accelerator='+',
+            accelerator="+",
         )
         menubar.add_cascade(label="Animate", underline=1, menu=animatemenu)
 
         helpmenu = Menu(menubar, tearoff=0)
-        helpmenu.add_command(label='About', underline=0, command=self.about)
+        helpmenu.add_command(label="About", underline=0, command=self.about)
         helpmenu.add_command(
-            label='Instructions', underline=0, command=self.help, accelerator='F1'
+            label="Instructions", underline=0, command=self.help, accelerator="F1"
         )
-        menubar.add_cascade(label='Help', underline=0, menu=helpmenu)
+        menubar.add_cascade(label="Help", underline=0, menu=helpmenu)
 
         parent.config(menu=menubar)
 
     def _init_feedback(self, parent):
         self._feedbackframe = feedbackframe = Frame(parent)
-        feedbackframe.pack(fill='x', side='bottom', padx=3, pady=3)
+        feedbackframe.pack(fill="x", side="bottom", padx=3, pady=3)
         self._lastoper_label = Label(
-            feedbackframe, text='Last Operation:', font=self._font
+            feedbackframe, text="Last Operation:", font=self._font
         )
-        self._lastoper_label.pack(side='left')
-        lastoperframe = Frame(feedbackframe, relief='sunken', border=1)
-        lastoperframe.pack(fill='x', side='right', expand=1, padx=5)
+        self._lastoper_label.pack(side="left")
+        lastoperframe = Frame(feedbackframe, relief="sunken", border=1)
+        lastoperframe.pack(fill="x", side="right", expand=1, padx=5)
         self._lastoper1 = Label(
-            lastoperframe, foreground='#007070', background='#f0f0f0', font=self._font
+            lastoperframe, foreground="#007070", background="#f0f0f0", font=self._font
         )
         self._lastoper2 = Label(
             lastoperframe,
-            anchor='w',
+            anchor="w",
             width=30,
-            foreground='#004040',
-            background='#f0f0f0',
+            foreground="#004040",
+            background="#f0f0f0",
             font=self._font,
         )
-        self._lastoper1.pack(side='left')
-        self._lastoper2.pack(side='left', fill='x', expand=1)
+        self._lastoper1.pack(side="left")
+        self._lastoper2.pack(side="left", fill="x", expand=1)
 
     def _init_canvas(self, parent):
         self._cframe = CanvasFrame(
             parent,
-            background='white',
+            background="white",
             width=525,
             closeenough=10,
             border=2,
-            relief='sunken',
+            relief="sunken",
         )
-        self._cframe.pack(expand=1, fill='both', side='top', pady=2)
+        self._cframe.pack(expand=1, fill="both", side="top", pady=2)
         canvas = self._canvas = self._cframe.canvas()
 
         self._stackwidgets = []
         self._rtextwidgets = []
         self._titlebar = canvas.create_rectangle(
-            0, 0, 0, 0, fill='#c0f0f0', outline='black'
+            0, 0, 0, 0, fill="#c0f0f0", outline="black"
         )
-        self._exprline = canvas.create_line(0, 0, 0, 0, dash='.')
-        self._stacktop = canvas.create_line(0, 0, 0, 0, fill='#408080')
+        self._exprline = canvas.create_line(0, 0, 0, 0, dash=".")
+        self._stacktop = canvas.create_line(0, 0, 0, 0, fill="#408080")
         size = self._size.get() + 4
         self._stacklabel = TextWidget(
-            canvas, 'Stack', color='#004040', font=self._boldfont
+            canvas, "Stack", color="#004040", font=self._boldfont
         )
         self._rtextlabel = TextWidget(
-            canvas, 'Remaining Text', color='#004040', font=self._boldfont
+            canvas, "Remaining Text", color="#004040", font=self._boldfont
         )
         self._cframe.add_widget(self._stacklabel)
         self._cframe.add_widget(self._rtextlabel)
@@ -448,7 +448,7 @@ class ShiftReduceApp(object):
     #########################################
 
     def _redraw(self):
-        scrollregion = self._canvas['scrollregion'].split()
+        scrollregion = self._canvas["scrollregion"].split()
         (cx1, cy1, cx2, cy2) = [int(c) for c in scrollregion]
 
         # Delete the old stack & rtext widgets.
@@ -476,17 +476,17 @@ class ShiftReduceApp(object):
         for tok in self._parser.stack():
             if isinstance(tok, Tree):
                 attribs = {
-                    'tree_color': '#4080a0',
-                    'tree_width': 2,
-                    'node_font': self._boldfont,
-                    'node_color': '#006060',
-                    'leaf_color': '#006060',
-                    'leaf_font': self._font,
+                    "tree_color": "#4080a0",
+                    "tree_width": 2,
+                    "node_font": self._boldfont,
+                    "node_color": "#006060",
+                    "leaf_color": "#006060",
+                    "leaf_font": self._font,
                 }
                 widget = tree_to_treesegment(self._canvas, tok, **attribs)
-                widget.label()['color'] = '#000000'
+                widget.label()["color"] = "#000000"
             else:
-                widget = TextWidget(self._canvas, tok, color='#000000', font=self._font)
+                widget = TextWidget(self._canvas, tok, color="#000000", font=self._font)
             widget.bind_click(self._popup_reduce)
             self._stackwidgets.append(widget)
             self._cframe.add_widget(widget, stackx, y)
@@ -495,7 +495,7 @@ class ShiftReduceApp(object):
         # Draw the remaining text.
         rtextwidth = 0
         for tok in self._parser.remaining_text():
-            widget = TextWidget(self._canvas, tok, color='#000000', font=self._font)
+            widget = TextWidget(self._canvas, tok, color="#000000", font=self._font)
             self._rtextwidgets.append(widget)
             self._cframe.add_widget(widget, rtextwidth, y)
             rtextwidth = widget.bbox()[2] + 4
@@ -541,7 +541,7 @@ class ShiftReduceApp(object):
 
     def _highlight_productions(self):
         # Highlight the productions that can be reduced.
-        self._prodlist.selection_clear(0, 'end')
+        self._prodlist.selection_clear(0, "end")
         for prod in self._parser.reducible_productions():
             index = self._productions.index(prod)
             self._prodlist.selection_set(index)
@@ -558,8 +558,8 @@ class ShiftReduceApp(object):
 
     def reset(self, *e):
         self._parser.initialize(self._sent)
-        self._lastoper1['text'] = 'Reset App'
-        self._lastoper2['text'] = ''
+        self._lastoper1["text"] = "Reset App"
+        self._lastoper2["text"] = ""
         self._redraw()
 
     def step(self, *e):
@@ -569,19 +569,19 @@ class ShiftReduceApp(object):
             return True
         else:
             if list(self._parser.parses()):
-                self._lastoper1['text'] = 'Finished:'
-                self._lastoper2['text'] = 'Success'
+                self._lastoper1["text"] = "Finished:"
+                self._lastoper2["text"] = "Success"
             else:
-                self._lastoper1['text'] = 'Finished:'
-                self._lastoper2['text'] = 'Failure'
+                self._lastoper1["text"] = "Finished:"
+                self._lastoper2["text"] = "Failure"
 
     def shift(self, *e):
         if self._animating_lock:
             return
         if self._parser.shift():
             tok = self._parser.stack()[-1]
-            self._lastoper1['text'] = 'Shift:'
-            self._lastoper2['text'] = '%r' % tok
+            self._lastoper1["text"] = "Shift:"
+            self._lastoper2["text"] = "%r" % tok
             if self._animate.get():
                 self._animate_shift()
             else:
@@ -594,8 +594,8 @@ class ShiftReduceApp(object):
             return
         production = self._parser.reduce()
         if production:
-            self._lastoper1['text'] = 'Reduce:'
-            self._lastoper2['text'] = '%s' % production
+            self._lastoper1["text"] = "Reduce:"
+            self._lastoper2["text"] = "%s" % production
             if self._animate.get():
                 self._animate_reduce()
             else:
@@ -648,24 +648,24 @@ class ShiftReduceApp(object):
         try:
             ShowText(
                 self._top,
-                'Help: Shift-Reduce Parser Application',
-                (__doc__ or '').strip(),
+                "Help: Shift-Reduce Parser Application",
+                (__doc__ or "").strip(),
                 width=75,
-                font='fixed',
+                font="fixed",
             )
         except:
             ShowText(
                 self._top,
-                'Help: Shift-Reduce Parser Application',
-                (__doc__ or '').strip(),
+                "Help: Shift-Reduce Parser Application",
+                (__doc__ or "").strip(),
                 width=75,
             )
 
     def about(self, *e):
         ABOUT = "NLTK Shift-Reduce Parser Application\n" + "Written by Edward Loper"
-        TITLE = 'About: Shift-Reduce Parser Application'
+        TITLE = "About: Shift-Reduce Parser Application"
         try:
-            from six.moves.tkinter_messagebox import Message
+            from tkinter.messagebox import Message
 
             Message(message=ABOUT, title=TITLE).show()
         except:
@@ -677,14 +677,14 @@ class ShiftReduceApp(object):
     def set_grammar(self, grammar):
         self._parser.set_grammar(grammar)
         self._productions = list(grammar.productions())
-        self._prodlist.delete(0, 'end')
+        self._prodlist.delete(0, "end")
         for production in self._productions:
-            self._prodlist.insert('end', (' %s' % production))
+            self._prodlist.insert("end", (" %s" % production))
 
     def edit_sentence(self, *e):
         sentence = " ".join(self._sent)
-        title = 'Edit Text'
-        instr = 'Enter a new sentence to parse.'
+        title = "Edit Text"
+        instr = "Enter a new sentence to parse."
         EntryDialog(self._top, sentence, instr, self.set_sentence, title)
 
     def set_sentence(self, sent):
@@ -698,13 +698,13 @@ class ShiftReduceApp(object):
     def _toggle_grammar(self, *e):
         if self._show_grammar.get():
             self._prodframe.pack(
-                fill='both', side='left', padx=2, after=self._feedbackframe
+                fill="both", side="left", padx=2, after=self._feedbackframe
             )
-            self._lastoper1['text'] = 'Show Grammar'
+            self._lastoper1["text"] = "Show Grammar"
         else:
             self._prodframe.pack_forget()
-            self._lastoper1['text'] = 'Hide Grammar'
-        self._lastoper2['text'] = ''
+            self._lastoper1["text"] = "Hide Grammar"
+        self._lastoper2["text"] = ""
 
     def _prodlist_select(self, event):
         selection = self._prodlist.curselection()
@@ -713,15 +713,15 @@ class ShiftReduceApp(object):
         index = int(selection[0])
         production = self._parser.reduce(self._productions[index])
         if production:
-            self._lastoper1['text'] = 'Reduce:'
-            self._lastoper2['text'] = '%s' % production
+            self._lastoper1["text"] = "Reduce:"
+            self._lastoper2["text"] = "%s" % production
             if self._animate.get():
                 self._animate_reduce()
             else:
                 self._redraw()
         else:
             # Reset the production selections.
-            self._prodlist.selection_clear(0, 'end')
+            self._prodlist.selection_clear(0, "end")
             for prod in self._parser.reducible_productions():
                 index = self._productions.index(prod)
                 self._prodlist.selection_set(index)
@@ -732,7 +732,7 @@ class ShiftReduceApp(object):
         if len(productions) == 0:
             return
 
-        self._reduce_menu.delete(0, 'end')
+        self._reduce_menu.delete(0, "end")
         for production in productions:
             self._reduce_menu.add_command(label=str(production), command=self.reduce)
         self._reduce_menu.post(
@@ -806,7 +806,7 @@ class ShiftReduceApp(object):
             if not isinstance(tok, Tree):
                 raise ValueError()
             label = TextWidget(
-                self._canvas, str(tok.label()), color='#006060', font=self._boldfont
+                self._canvas, str(tok.label()), color="#006060", font=self._boldfont
             )
             widget = TreeSegmentWidget(self._canvas, label, widgets, width=2)
             (x1, y1, x2, y2) = self._stacklabel.bbox()
@@ -870,9 +870,9 @@ class ShiftReduceApp(object):
             rhslen = len(self._productions[index].rhs())
             for stackwidget in self._stackwidgets[-rhslen:]:
                 if isinstance(stackwidget, TreeSegmentWidget):
-                    stackwidget.label()['color'] = '#00a000'
+                    stackwidget.label()["color"] = "#00a000"
                 else:
-                    stackwidget['color'] = '#00a000'
+                    stackwidget["color"] = "#00a000"
 
         # Remember what production we're hovering over.
         self._hover = index
@@ -884,9 +884,9 @@ class ShiftReduceApp(object):
         self._hover = -1
         for stackwidget in self._stackwidgets:
             if isinstance(stackwidget, TreeSegmentWidget):
-                stackwidget.label()['color'] = 'black'
+                stackwidget.label()["color"] = "black"
             else:
-                stackwidget['color'] = 'black'
+                stackwidget["color"] = "black"
 
 
 def app():
@@ -897,7 +897,7 @@ def app():
 
     from nltk.grammar import Nonterminal, Production, CFG
 
-    nonterminals = 'S VP NP PP P N Name V Det'
+    nonterminals = "S VP NP PP P N Name V Det"
     (S, VP, NP, PP, P, N, Name, V, Det) = [Nonterminal(s) for s in nonterminals.split()]
 
     productions = (
@@ -910,28 +910,28 @@ def app():
         Production(VP, [V, NP]),
         Production(PP, [P, NP]),
         # Lexical Productions
-        Production(NP, ['I']),
-        Production(Det, ['the']),
-        Production(Det, ['a']),
-        Production(N, ['man']),
-        Production(V, ['saw']),
-        Production(P, ['in']),
-        Production(P, ['with']),
-        Production(N, ['park']),
-        Production(N, ['dog']),
-        Production(N, ['statue']),
-        Production(Det, ['my']),
+        Production(NP, ["I"]),
+        Production(Det, ["the"]),
+        Production(Det, ["a"]),
+        Production(N, ["man"]),
+        Production(V, ["saw"]),
+        Production(P, ["in"]),
+        Production(P, ["with"]),
+        Production(N, ["park"]),
+        Production(N, ["dog"]),
+        Production(N, ["statue"]),
+        Production(Det, ["my"]),
     )
 
     grammar = CFG(S, productions)
 
     # tokenize the sentence
-    sent = 'my dog saw a man in the park with a statue'.split()
+    sent = "my dog saw a man in the park with a statue".split()
 
     ShiftReduceApp(grammar, sent).mainloop()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     app()
 
-__all__ = ['app']
+__all__ = ["app"]
