@@ -1,6 +1,6 @@
 # Natural Language Toolkit: graphical representations package
 #
-# Copyright (C) 2001-2017 NLTK Project
+# Copyright (C) 2001-2020 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 #         Steven Bird <stevenbird1@gmail.com>
 # URL: <http://nltk.org/>
@@ -8,15 +8,20 @@
 
 # Import Tkinter-based modules if Tkinter is installed
 try:
-    from six.moves import tkinter
+    import tkinter
 except ImportError:
     import warnings
-    warnings.warn("nltk.draw package not loaded "
-                  "(please install Tkinter library).")
+
+    warnings.warn("nltk.draw package not loaded " "(please install Tkinter library).")
 else:
     from nltk.draw.cfg import ProductionList, CFGEditor, CFGDemo
-    from nltk.draw.tree import (TreeSegmentWidget, tree_to_treesegment,
-                      TreeWidget, TreeView, draw_trees)
+    from nltk.draw.tree import (
+        TreeSegmentWidget,
+        tree_to_treesegment,
+        TreeWidget,
+        TreeView,
+        draw_trees,
+    )
     from nltk.draw.table import Table
 
 from nltk.draw.dispersion import dispersion_plot
@@ -24,4 +29,5 @@ from nltk.draw.dispersion import dispersion_plot
 # skip doctests from this package
 def setup_module(module):
     from nose import SkipTest
+
     raise SkipTest("nltk.draw examples are not doctests")
