@@ -2,12 +2,10 @@
 #
 # Author: David McClosky <dmcc@bigasterisk.com>
 #
-# Copyright (C) 2001-2019 NLTK Project
+# Copyright (C) 2001-2020 NLTK Project
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
 
-from __future__ import print_function
-
 from nltk.parse.api import ParserI
 from nltk.tree import Tree
 
@@ -81,7 +79,7 @@ See http://pypi.python.org/pypi/bllipparser/ for more information
 on BLLIP Parser's Python interface.
 """
 
-__all__ = ['BllipParser']
+__all__ = ["BllipParser"]
 
 # this block allows this module to be imported even if bllipparser isn't
 # available
@@ -102,7 +100,7 @@ except ImportError as ie:
 def _ensure_ascii(words):
     try:
         for i, word in enumerate(words):
-            word.decode('ascii')
+            word.decode("ascii")
     except UnicodeDecodeError:
         raise ValueError(
             "Token %d (%r) is non-ASCII. BLLIP Parser "
@@ -262,19 +260,19 @@ def demo():
 
     from nltk.data import find
 
-    model_dir = find('models/bllip_wsj_no_aux').path
+    model_dir = find("models/bllip_wsj_no_aux").path
 
-    print('Loading BLLIP Parsing models...')
+    print("Loading BLLIP Parsing models...")
     # the easiest way to get started is to use a unified model
     bllip = BllipParser.from_unified_model_dir(model_dir)
-    print('Done.')
+    print("Done.")
 
-    sentence1 = 'British left waffles on Falklands .'.split()
-    sentence2 = 'I saw the man with the telescope .'.split()
+    sentence1 = "British left waffles on Falklands .".split()
+    sentence2 = "I saw the man with the telescope .".split()
     # this sentence is known to fail under the WSJ parsing model
-    fail1 = '# ! ? : -'.split()
+    fail1 = "# ! ? : -".split()
     for sentence in (sentence1, sentence2, fail1):
-        print('Sentence: %r' % ' '.join(sentence))
+        print("Sentence: %r" % " ".join(sentence))
         try:
             tree = next(bllip.parse(sentence))
             print(tree)
@@ -283,22 +281,22 @@ def demo():
 
     # n-best parsing demo
     for i, parse in enumerate(bllip.parse(sentence1)):
-        print('parse %d:\n%s' % (i, parse))
+        print("parse %d:\n%s" % (i, parse))
 
     # using external POS tag constraints
     print(
         "forcing 'tree' to be 'NN':",
-        next(bllip.tagged_parse([('A', None), ('tree', 'NN')])),
+        next(bllip.tagged_parse([("A", None), ("tree", "NN")])),
     )
     print(
         "forcing 'A' to be 'DT' and 'tree' to be 'NNP':",
-        next(bllip.tagged_parse([('A', 'DT'), ('tree', 'NNP')])),
+        next(bllip.tagged_parse([("A", "DT"), ("tree", "NNP")])),
     )
     # constraints don't have to make sense... (though on more complicated
     # sentences, they may cause the parse to fail)
     print(
         "forcing 'A' to be 'NNP':",
-        next(bllip.tagged_parse([('A', 'NNP'), ('tree', None)])),
+        next(bllip.tagged_parse([("A", "NNP"), ("tree", None)])),
     )
 
 
@@ -309,6 +307,6 @@ def setup_module(module):
         _ensure_bllip_import_or_error()
     except ImportError:
         raise SkipTest(
-            'doctests from nltk.parse.bllip are skipped because '
-            'the bllipparser module is not installed'
+            "doctests from nltk.parse.bllip are skipped because "
+            "the bllipparser module is not installed"
         )
