@@ -1,20 +1,15 @@
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import, unicode_literals
 
 import unittest
 import contextlib
 import sys
+from io import StringIO
 
 from nose import with_setup
 
 from nltk.corpus import gutenberg
 from nltk.text import Text
 
-try:
-    from StringIO import StringIO
-except ImportError as e:
-    from io import StringIO
-
 
 @contextlib.contextmanager
 def stdout_redirect(where):
