@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # Natural Language Toolkit: Tokenizers
 #
-# Copyright (C) 2001-2019 NLTK Project
+# Copyright (C) 2001-2020 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 #         Steven Bird <stevenbird1@gmail.com> (minor additions)
 # Contributors: matthewmc, clouds56
@@ -65,6 +65,7 @@ import re
 from nltk.data import load
 from nltk.tokenize.casual import TweetTokenizer, casual_tokenize
 from nltk.tokenize.mwe import MWETokenizer
+from nltk.tokenize.destructive import NLTKWordTokenizer
 from nltk.tokenize.punkt import PunktSentenceTokenizer
 from nltk.tokenize.regexp import (
     RegexpTokenizer,
@@ -88,10 +89,11 @@ from nltk.tokenize.toktok import ToktokTokenizer
 from nltk.tokenize.treebank import TreebankWordTokenizer
 from nltk.tokenize.util import string_span_tokenize, regexp_span_tokenize
 from nltk.tokenize.stanford_segmenter import StanfordSegmenter
+from nltk.tokenize.sonority_sequencing import SyllableTokenizer
 
 
 # Standard sentence tokenizer.
-def sent_tokenize(text, language='english'):
+def sent_tokenize(text, language="english"):
     """
     Return a sentence-tokenized copy of *text*,
     using NLTK's recommended sentence tokenizer
@@ -101,31 +103,15 @@ def sent_tokenize(text, language='english'):
     :param text: text to split into sentences
     :param language: the model name in the Punkt corpus
     """
-    tokenizer = load('tokenizers/punkt/{0}.pickle'.format(language))
+    tokenizer = load("tokenizers/punkt/{0}.pickle".format(language))
     return tokenizer.tokenize(text)
 
 
 # Standard word tokenizer.
-_treebank_word_tokenizer = TreebankWordTokenizer()
-
-# See discussion on https://github.com/nltk/nltk/pull/1437
-# Adding to TreebankWordTokenizer, nltk.word_tokenize now splits on
-# - chervon quotes u'\xab' and u'\xbb' .
-# - unicode quotes u'\u2018', u'\u2019', u'\u201c' and u'\u201d'
-# See https://github.com/nltk/nltk/issues/1995#issuecomment-376741608
-# Also, behavior of splitting on clitics now follows Stanford CoreNLP
-# - clitics covered (?!re|ve|ll|m|t|s|d)(\w)\b
-improved_open_quote_regex = re.compile(u'([«“‘„]|[`]+)', re.U)
-improved_open_single_quote_regex = re.compile(r"(?i)(\')(?!re|ve|ll|m|t|s|d)(\w)\b", re.U)
-improved_close_quote_regex = re.compile(u'([»”’])', re.U)
-improved_punct_regex = re.compile(r'([^\.])(\.)([\]\)}>"\'' u'»”’ ' r']*)\s*$', re.U)
-_treebank_word_tokenizer.STARTING_QUOTES.insert(0, (improved_open_quote_regex, r' \1 '))
-_treebank_word_tokenizer.STARTING_QUOTES.append((improved_open_single_quote_regex, r'\1 \2'))
-_treebank_word_tokenizer.ENDING_QUOTES.insert(0, (improved_close_quote_regex, r' \1 '))
-_treebank_word_tokenizer.PUNCTUATION.insert(0, (improved_punct_regex, r'\1 \2 \3 '))
+_treebank_word_tokenizer = NLTKWordTokenizer()
 
 
-def word_tokenize(text, language='english', preserve_line=False):
+def word_tokenize(text, language="english", preserve_line=False):
     """
     Return a tokenized copy of *text*,
     using NLTK's recommended word tokenizer
