@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # Natural Language Toolkit: Machine Translation
 #
-# Copyright (C) 2001-2019 NLTK Project
+# Copyright (C) 2001-2020 NLTK Project
 # Author: Uday Krishna <udaykrishna5@gmail.com>
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
@@ -11,9 +11,10 @@ from nltk.stem.porter import PorterStemmer
 from nltk.corpus import wordnet
 from itertools import chain, product
 
+
 def _generate_enums(hypothesis, reference, preprocess=str.lower):
     """
-    Takes in string inputs for hypothesis and reference and returns 
+    Takes in string inputs for hypothesis and reference and returns
     enumerated word lists for each of them
 
     :param hypothesis: hypothesis string
@@ -29,23 +30,25 @@ def _generate_enums(hypothesis, reference, preprocess=str.lower):
     reference_list = list(enumerate(preprocess(reference).split()))
     return hypothesis_list, reference_list
 
+
 def exact_match(hypothesis, reference):
     """
-    matches exact words in hypothesis and reference 
-    and returns a word mapping based on the enumerated 
+    matches exact words in hypothesis and reference
+    and returns a word mapping based on the enumerated
     word id between hypothesis and reference
 
     :param hypothesis: hypothesis string
     :type hypothesis: str
     :param reference: reference string
     :type reference: str
-    :return: enumerated matched tuples, enumerated unmatched hypothesis tuples, 
+    :return: enumerated matched tuples, enumerated unmatched hypothesis tuples,
              enumerated unmatched reference tuples
     :rtype: list of 2D tuples, list of 2D tuples,  list of 2D tuples
     """
     hypothesis_list, reference_list = _generate_enums(hypothesis, reference)
     return _match_enums(hypothesis_list, reference_list)
-    
+
+
 def _match_enums(enum_hypothesis_list, enum_reference_list):
     """
     matches exact words in hypothesis and reference and returns
@@ -56,7 +59,7 @@ def _match_enums(enum_hypothesis_list, enum_reference_list):
     :type enum_hypothesis_list: list of tuples
     :param enum_reference_list: enumerated reference list
     :type enum_reference_list: list of 2D tuples
-    :return: enumerated matched tuples, enumerated unmatched hypothesis tuples, 
+    :return: enumerated matched tuples, enumerated unmatched hypothesis tuples,
              enumerated unmatched reference tuples
     :rtype: list of 2D tuples, list of 2D tuples,  list of 2D tuples
     """
@@ -64,16 +67,21 @@ def _match_enums(enum_hypothesis_list, enum_reference_list):
     for i in range(len(enum_hypothesis_list))[::-1]:
         for j in range(len(enum_reference_list))[::-1]:
             if enum_hypothesis_list[i][1] == enum_reference_list[j][1]:
-                word_match.append((enum_hypothesis_list[i][0],enum_reference_list[j][0]))
-                (enum_hypothesis_list.pop(i)[1],enum_reference_list.pop(j)[1])
+                word_match.append(
+                    (enum_hypothesis_list[i][0], enum_reference_list[j][0])
+                )
+                (enum_hypothesis_list.pop(i)[1], enum_reference_list.pop(j)[1])
                 break
     return word_match, enum_hypothesis_list, enum_reference_list
-                              
-def _enum_stem_match(enum_hypothesis_list, enum_reference_list, stemmer = PorterStemmer()):
+
+
+def _enum_stem_match(
+    enum_hypothesis_list, enum_reference_list, stemmer=PorterStemmer()
+):
     """
-    Stems each word and matches them in hypothesis and reference 
-    and returns a word mapping between enum_hypothesis_list and 
-    enum_reference_list based on the enumerated word id. The function also 
+    Stems each word and matches them in hypothesis and reference
+    and returns a word mapping between enum_hypothesis_list and
+    enum_reference_list based on the enumerated word id. The function also
     returns a enumerated list of unmatched words for hypothesis and reference.
 
     :param enum_hypothesis_list:
@@ -82,34 +90,44 @@ def _enum_stem_match(enum_hypothesis_list, enum_reference_list, stemmer = Porter
     :type enum_reference_list:
     :param stemmer: nltk.stem.api.StemmerI object (default PorterStemmer())
     :type stemmer: nltk.stem.api.StemmerI or any class that implements a stem method
-    :return: enumerated matched tuples, enumerated unmatched hypothesis tuples, 
+    :return: enumerated matched tuples, enumerated unmatched hypothesis tuples,
              enumerated unmatched reference tuples
     :rtype: list of 2D tuples, list of 2D tuples,  list of 2D tuples
     """
-    stemmed_enum_list1 = [(word_pair[0],stemmer.stem(word_pair[1])) \
-                          for word_pair in enum_hypothesis_list]
+    stemmed_enum_list1 = [
+        (word_pair[0], stemmer.stem(word_pair[1])) for word_pair in enum_hypothesis_list
+    ]
 
-    stemmed_enum_list2 = [(word_pair[0],stemmer.stem(word_pair[1])) \
-                          for word_pair in enum_reference_list]
+    stemmed_enum_list2 = [
+        (word_pair[0], stemmer.stem(word_pair[1])) for word_pair in enum_reference_list
+    ]
 
-    word_match, enum_unmat_hypo_list, enum_unmat_ref_list = \
-                    _match_enums(stemmed_enum_list1, stemmed_enum_list2)
+    word_match, enum_unmat_hypo_list, enum_unmat_ref_list = _match_enums(
+        stemmed_enum_list1, stemmed_enum_list2
+    )
 
-    enum_unmat_hypo_list = list(zip(*enum_unmat_hypo_list)) if len(enum_unmat_hypo_list)>0 else []
+    enum_unmat_hypo_list = (
+        list(zip(*enum_unmat_hypo_list)) if len(enum_unmat_hypo_list) > 0 else []
+    )
 
-    enum_unmat_ref_list = list(zip(*enum_unmat_ref_list)) if len(enum_unmat_ref_list)>0 else []
+    enum_unmat_ref_list = (
+        list(zip(*enum_unmat_ref_list)) if len(enum_unmat_ref_list) > 0 else []
+    )
 
-    enum_hypothesis_list = list(filter(lambda x:x[0] not in enum_unmat_hypo_list,  
-                                       enum_hypothesis_list))
+    enum_hypothesis_list = list(
+        filter(lambda x: x[0] not in enum_unmat_hypo_list, enum_hypothesis_list)
+    )
 
-    enum_reference_list = list(filter(lambda x:x[0] not in enum_unmat_ref_list, 
-                                      enum_reference_list))
+    enum_reference_list = list(
+        filter(lambda x: x[0] not in enum_unmat_ref_list, enum_reference_list)
+    )
 
     return word_match, enum_hypothesis_list, enum_reference_list
 
-def stem_match(hypothesis, reference, stemmer = PorterStemmer()):
+
+def stem_match(hypothesis, reference, stemmer=PorterStemmer()):
     """
-    Stems each word and matches them in hypothesis and reference 
+    Stems each word and matches them in hypothesis and reference
     and returns a word mapping between hypothesis and reference
 
     :param hypothesis:
@@ -117,19 +135,20 @@ def stem_match(hypothesis, reference, stemmer = PorterStemmer()):
     :param reference:
     :type reference:
     :param stemmer: nltk.stem.api.StemmerI object (default PorterStemmer())
-    :type stemmer: nltk.stem.api.StemmerI or any class that 
+    :type stemmer: nltk.stem.api.StemmerI or any class that
                    implements a stem method
-    :return: enumerated matched tuples, enumerated unmatched hypothesis tuples, 
+    :return: enumerated matched tuples, enumerated unmatched hypothesis tuples,
              enumerated unmatched reference tuples
     :rtype: list of 2D tuples, list of 2D tuples,  list of 2D tuples
     """
     enum_hypothesis_list, enum_reference_list = _generate_enums(hypothesis, reference)
-    return _enum_stem_match(enum_hypothesis_list, enum_reference_list, stemmer = stemmer)
+    return _enum_stem_match(enum_hypothesis_list, enum_reference_list, stemmer=stemmer)
 
-def _enum_wordnetsyn_match(enum_hypothesis_list, enum_reference_list, wordnet = wordnet):
+
+def _enum_wordnetsyn_match(enum_hypothesis_list, enum_reference_list, wordnet=wordnet):
     """
-    Matches each word in reference to a word in hypothesis 
-    if any synonym of a hypothesis word is the exact match 
+    Matches each word in reference to a word in hypothesis
+    if any synonym of a hypothesis word is the exact match
     to the reference word.
 
     :param enum_hypothesis_list: enumerated hypothesis list
@@ -142,41 +161,54 @@ def _enum_wordnetsyn_match(enum_hypothesis_list, enum_reference_list, wordnet =
     """
     word_match = []
     for i in range(len(enum_hypothesis_list))[::-1]:
-        hypothesis_syns = set(chain(*[[lemma.name() for lemma in synset.lemmas() 
-                                        if lemma.name().find('_')<0] 
-                                       for synset in \
-                                           wordnet.synsets(
-                                               enum_hypothesis_list[i][1])]
-                                               )).union({enum_hypothesis_list[i][1]})
+        hypothesis_syns = set(
+            chain(
+                *[
+                    [
+                        lemma.name()
+                        for lemma in synset.lemmas()
+                        if lemma.name().find("_") < 0
+                    ]
+                    for synset in wordnet.synsets(enum_hypothesis_list[i][1])
+                ]
+            )
+        ).union({enum_hypothesis_list[i][1]})
         for j in range(len(enum_reference_list))[::-1]:
             if enum_reference_list[j][1] in hypothesis_syns:
-                word_match.append((enum_hypothesis_list[i][0],enum_reference_list[j][0]))
-                enum_hypothesis_list.pop(i),enum_reference_list.pop(j)
+                word_match.append(
+                    (enum_hypothesis_list[i][0], enum_reference_list[j][0])
+                )
+                enum_hypothesis_list.pop(i), enum_reference_list.pop(j)
                 break
     return word_match, enum_hypothesis_list, enum_reference_list
 
-def wordnetsyn_match(hypothesis, reference, wordnet = wordnet):
+
+def wordnetsyn_match(hypothesis, reference, wordnet=wordnet):
     """
-    Matches each word in reference to a word in hypothesis if any synonym 
+    Matches each word in reference to a word in hypothesis if any synonym
     of a hypothesis word is the exact match to the reference word.
-    
+
     :param hypothesis: hypothesis string
     :param reference: reference string
     :param wordnet: a wordnet corpus reader object (default nltk.corpus.wordnet)
     :type wordnet: WordNetCorpusReader
     :return: list of mapped tuples
-    :rtype: list of tuples 
+    :rtype: list of tuples
     """
     enum_hypothesis_list, enum_reference_list = _generate_enums(hypothesis, reference)
-    return _enum_wordnetsyn_match(enum_hypothesis_list, enum_reference_list, wordnet = wordnet)
+    return _enum_wordnetsyn_match(
+        enum_hypothesis_list, enum_reference_list, wordnet=wordnet
+    )
 
-def _enum_allign_words(enum_hypothesis_list, enum_reference_list, 
-                       stemmer=PorterStemmer(), wordnet = wordnet):
+
+def _enum_allign_words(
+    enum_hypothesis_list, enum_reference_list, stemmer=PorterStemmer(), wordnet=wordnet
+):
     """
-    Aligns/matches words in the hypothesis to reference by sequentially 
-    applying exact match, stemmed match and wordnet based synonym match. 
+    Aligns/matches words in the hypothesis to reference by sequentially
+    applying exact match, stemmed match and wordnet based synonym match.
     in case there are multiple matches the match which has the least number
-    of crossing is chosen. Takes enumerated list as input instead of 
+    of crossing is chosen. Takes enumerated list as input instead of
     string input
 
     :param enum_hypothesis_list: enumerated hypothesis list
@@ -185,28 +217,35 @@ def _enum_allign_words(enum_hypothesis_list, enum_reference_list,
     :type stemmer: nltk.stem.api.StemmerI or any class that implements a stem method
     :param wordnet: a wordnet corpus reader object (default nltk.corpus.wordnet)
     :type wordnet: WordNetCorpusReader
-    :return: sorted list of matched tuples, unmatched hypothesis list, 
+    :return: sorted list of matched tuples, unmatched hypothesis list,
              unmatched reference list
     :rtype: list of tuples, list of tuples, list of tuples
     """
-    exact_matches, enum_hypothesis_list, enum_reference_list = \
-        _match_enums(enum_hypothesis_list, enum_reference_list)
+    exact_matches, enum_hypothesis_list, enum_reference_list = _match_enums(
+        enum_hypothesis_list, enum_reference_list
+    )
 
-    stem_matches, enum_hypothesis_list, enum_reference_list = \
-        _enum_stem_match(enum_hypothesis_list, enum_reference_list,
-                         stemmer = stemmer)
+    stem_matches, enum_hypothesis_list, enum_reference_list = _enum_stem_match(
+        enum_hypothesis_list, enum_reference_list, stemmer=stemmer
+    )
 
-    wns_matches, enum_hypothesis_list, enum_reference_list = \
-        _enum_wordnetsyn_match(enum_hypothesis_list, enum_reference_list, 
-                               wordnet = wordnet)
+    wns_matches, enum_hypothesis_list, enum_reference_list = _enum_wordnetsyn_match(
+        enum_hypothesis_list, enum_reference_list, wordnet=wordnet
+    )
 
-    return (sorted(exact_matches + stem_matches + wns_matches, key=lambda wordpair:wordpair[0]), 
-            enum_hypothesis_list, enum_reference_list)
+    return (
+        sorted(
+            exact_matches + stem_matches + wns_matches, key=lambda wordpair: wordpair[0]
+        ),
+        enum_hypothesis_list,
+        enum_reference_list,
+    )
 
-def allign_words(hypothesis, reference, stemmer = PorterStemmer(), wordnet = wordnet):
+
+def allign_words(hypothesis, reference, stemmer=PorterStemmer(), wordnet=wordnet):
     """
-    Aligns/matches words in the hypothesis to reference by sequentially 
-    applying exact match, stemmed match and wordnet based synonym match. 
+    Aligns/matches words in the hypothesis to reference by sequentially
+    applying exact match, stemmed match and wordnet based synonym match.
     In case there are multiple matches the match which has the least number
     of crossing is chosen.
 
@@ -220,8 +259,10 @@ def allign_words(hypothesis, reference, stemmer = PorterStemmer(), wordnet = wor
     :rtype: list of tuples, list of tuples, list of tuples
     """
     enum_hypothesis_list, enum_reference_list = _generate_enums(hypothesis, reference)
-    return _enum_allign_words(enum_hypothesis_list, enum_reference_list, stemmer= stemmer,
-                             wordnet= wordnet)
+    return _enum_allign_words(
+        enum_hypothesis_list, enum_reference_list, stemmer=stemmer, wordnet=wordnet
+    )
+
 
 def _count_chunks(matches):
     """
@@ -233,29 +274,34 @@ def _count_chunks(matches):
     :return: Number of chunks a sentence is divided into post allignment
     :rtype: int
     """
-    i=0
+    i = 0
     chunks = 1
-    while(i<len(matches)-1):
-        if (matches[i+1][0]==matches[i][0]+1) and (matches[i+1][1]==matches[i][1]+1):
-            i+=1
+    while i < len(matches) - 1:
+        if (matches[i + 1][0] == matches[i][0] + 1) and (
+            matches[i + 1][1] == matches[i][1] + 1
+        ):
+            i += 1
             continue
-        i+=1
+        i += 1
         chunks += 1
     return chunks
-    
-def single_meteor_score(reference, 
-                        hypothesis, 
-                        preprocess = str.lower, 
-                        stemmer = PorterStemmer(), 
-                        wordnet = wordnet, 
-                        alpha=0.9, 
-                        beta=3, 
-                        gamma=0.5):
+
+
+def single_meteor_score(
+    reference,
+    hypothesis,
+    preprocess=str.lower,
+    stemmer=PorterStemmer(),
+    wordnet=wordnet,
+    alpha=0.9,
+    beta=3,
+    gamma=0.5,
+):
     """
-    Calculates METEOR score for single hypothesis and reference as per 
+    Calculates METEOR score for single hypothesis and reference as per
     "Meteor: An Automatic Metric for MT Evaluation with HighLevels of
-    Correlation with Human Judgments" by Alon Lavie and Abhaya Agarwal, 
-    in Proceedings of ACL. 
+    Correlation with Human Judgments" by Alon Lavie and Abhaya Agarwal,
+    in Proceedings of ACL.
     http://www.cs.cmu.edu/~alavie/METEOR/pdf/Lavie-Agarwal-2007-METEOR.pdf
 
 
@@ -267,11 +313,11 @@ def single_meteor_score(reference,
     >>> round(single_meteor_score(reference1, hypothesis1),4)
     0.7398
 
-        If there is no words match during the alignment the method returns the 
-        score as 0. We can safely  return a zero instead of raising a 
-        division by zero error as no match usually implies a bad translation. 
+        If there is no words match during the alignment the method returns the
+        score as 0. We can safely  return a zero instead of raising a
+        division by zero error as no match usually implies a bad translation.
 
-    >>> round(meteor_score('this is a cat', 'non matching hypothesis'),4) 
+    >>> round(meteor_score('this is a cat', 'non matching hypothesis'),4)
     0.0
 
     :param references: reference sentences
@@ -286,7 +332,7 @@ def single_meteor_score(reference,
     :type wordnet: WordNetCorpusReader
     :param alpha: parameter for controlling relative weights of precision and recall.
     :type alpha: float
-    :param beta: parameter for controlling shape of penalty as a 
+    :param beta: parameter for controlling shape of penalty as a
                  function of as a function of fragmentation.
     :type beta: float
     :param gamma: relative weight assigned to fragmentation penality.
@@ -294,42 +340,45 @@ def single_meteor_score(reference,
     :return: The sentence-level METEOR score.
     :rtype: float
     """
-    enum_hypothesis, enum_reference = _generate_enums(hypothesis, 
-                                                      reference, 
-                                                      preprocess = preprocess)
+    enum_hypothesis, enum_reference = _generate_enums(
+        hypothesis, reference, preprocess=preprocess
+    )
     translation_length = len(enum_hypothesis)
     reference_length = len(enum_reference)
-    matches, _, _ = _enum_allign_words(enum_hypothesis, enum_reference)
+    matches, _, _ = _enum_allign_words(enum_hypothesis, enum_reference, stemmer=stemmer)
     matches_count = len(matches)
     try:
-        precision = float(matches_count)/translation_length
-        recall = float(matches_count)/reference_length
-        fmean = (precision*recall)/(alpha*precision+(1-alpha)*recall)
+        precision = float(matches_count) / translation_length
+        recall = float(matches_count) / reference_length
+        fmean = (precision * recall) / (alpha * precision + (1 - alpha) * recall)
         chunk_count = float(_count_chunks(matches))
-        frag_frac = chunk_count/matches_count
+        frag_frac = chunk_count / matches_count
     except ZeroDivisionError:
-        return 0.0        
-    penalty = gamma*frag_frac**beta
-    return (1-penalty)*fmean
+        return 0.0
+    penalty = gamma * frag_frac ** beta
+    return (1 - penalty) * fmean
 
-def meteor_score(references, 
-                hypothesis,
-                preprocess = str.lower, 
-                stemmer = PorterStemmer(), 
-                wordnet = wordnet, 
-                alpha=0.9, 
-                beta=3, 
-                gamma=0.5):
+
+def meteor_score(
+    references,
+    hypothesis,
+    preprocess=str.lower,
+    stemmer=PorterStemmer(),
+    wordnet=wordnet,
+    alpha=0.9,
+    beta=3,
+    gamma=0.5,
+):
     """
-    Calculates METEOR score for hypothesis with multiple references as 
-    described in "Meteor: An Automatic Metric for MT Evaluation with 
-    HighLevels of Correlation with Human Judgments" by Alon Lavie and 
-    Abhaya Agarwal, in Proceedings of ACL. 
+    Calculates METEOR score for hypothesis with multiple references as
+    described in "Meteor: An Automatic Metric for MT Evaluation with
+    HighLevels of Correlation with Human Judgments" by Alon Lavie and
+    Abhaya Agarwal, in Proceedings of ACL.
     http://www.cs.cmu.edu/~alavie/METEOR/pdf/Lavie-Agarwal-2007-METEOR.pdf
 
 
-    In case of multiple references the best score is chosen. This method 
-    iterates over single_meteor_score and picks the best pair among all 
+    In case of multiple references the best score is chosen. This method
+    iterates over single_meteor_score and picks the best pair among all
     the references for a given hypothesis
 
     >>> hypothesis1 = 'It is a guide to action which ensures that the military always obeys the commands of the party'
@@ -342,11 +391,11 @@ def meteor_score(references,
     >>> round(meteor_score([reference1, reference2, reference3], hypothesis1),4)
     0.7398
 
-        If there is no words match during the alignment the method returns the 
-        score as 0. We can safely  return a zero instead of raising a 
-        division by zero error as no match usually implies a bad translation. 
+        If there is no words match during the alignment the method returns the
+        score as 0. We can safely  return a zero instead of raising a
+        division by zero error as no match usually implies a bad translation.
 
-    >>> round(meteor_score(['this is a cat'], 'non matching hypothesis'),4) 
+    >>> round(meteor_score(['this is a cat'], 'non matching hypothesis'),4)
     0.0
 
     :param references: reference sentences
@@ -361,7 +410,7 @@ def meteor_score(references,
     :type wordnet: WordNetCorpusReader
     :param alpha: parameter for controlling relative weights of precision and recall.
     :type alpha: float
-    :param beta: parameter for controlling shape of penalty as a function 
+    :param beta: parameter for controlling shape of penalty as a function
                  of as a function of fragmentation.
     :type beta: float
     :param gamma: relative weight assigned to fragmentation penality.
@@ -369,10 +418,17 @@ def meteor_score(references,
     :return: The sentence-level METEOR score.
     :rtype: float
     """
-    return max([single_meteor_score(reference, 
-                                    hypothesis, 
-                                    stemmer = stemmer,
-                                    wordnet = wordnet, 
-                                    alpha = alpha, 
-                                    beta = beta, 
-                                    gamma = gamma) for reference in references])
+    return max(
+        [
+            single_meteor_score(
+                reference,
+                hypothesis,
+                stemmer=stemmer,
+                wordnet=wordnet,
+                alpha=alpha,
+                beta=beta,
+                gamma=gamma,
+            )
+            for reference in references
+        ]
+    )
